# mypy-boto3-workspaces<a id="mypy-boto3-workspaces"></a>

[![PyPI - mypy-boto3-workspaces](https://img.shields.io/pypi/v/mypy-boto3-workspaces.svg?color=blue)](https://pypi.org/project/mypy-boto3-workspaces)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-workspaces.svg?color=blue)](https://pypi.org/project/mypy-boto3-workspaces)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-workspaces?color=blue)](https://pypistats.org/packages/mypy-boto3-workspaces)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.WorkSpaces 1.17.72](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/workspaces.html#WorkSpaces)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.13.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-workspaces docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-workspaces](#mypy-boto3-workspaces)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `WorkSpaces` service.

```bash
python -m pip install boto3-stubs[workspaces]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[workspaces]` in your environment:
  `python -m pip install 'boto3-stubs[workspaces]'`

Both type checking and auto-complete should work for `WorkSpaces` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[workspaces]` in your environment:
  `python -m pip install 'boto3-stubs[workspaces]'`

Both type checking and auto-complete should work for `WorkSpaces` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[workspaces]` in your environment:
  `python -m pip install 'boto3-stubs[workspaces]'`
- Run `mypy` as usual

Type checking should work for `WorkSpaces` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[workspaces]` in your environment:
  `python -m pip install 'boto3-stubs[workspaces]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `WorkSpaces` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`WorkSpacesClient` provides annotations for `boto3.client("workspaces")`.

```python
import boto3

from mypy_boto3_workspaces import WorkSpacesClient

client: WorkSpacesClient = boto3.client("workspaces")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: WorkSpacesClient = session.client("workspaces")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_workspaces.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_workspaces import WorkSpacesClient
from mypy_boto3_workspaces.paginator import (
    DescribeAccountModificationsPaginator,
    DescribeIpGroupsPaginator,
    DescribeWorkspaceBundlesPaginator,
    DescribeWorkspaceDirectoriesPaginator,
    DescribeWorkspaceImagesPaginator,
    DescribeWorkspacesPaginator,
    DescribeWorkspacesConnectionStatusPaginator,
    ListAvailableManagementCidrRangesPaginator,
)

client: WorkSpacesClient = boto3.client("workspaces")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_account_modifications_paginator: DescribeAccountModificationsPaginator = client.get_paginator("describe_account_modifications")
describe_ip_groups_paginator: DescribeIpGroupsPaginator = client.get_paginator("describe_ip_groups")
describe_workspace_bundles_paginator: DescribeWorkspaceBundlesPaginator = client.get_paginator("describe_workspace_bundles")
describe_workspace_directories_paginator: DescribeWorkspaceDirectoriesPaginator = client.get_paginator("describe_workspace_directories")
describe_workspace_images_paginator: DescribeWorkspaceImagesPaginator = client.get_paginator("describe_workspace_images")
describe_workspaces_paginator: DescribeWorkspacesPaginator = client.get_paginator("describe_workspaces")
describe_workspaces_connection_status_paginator: DescribeWorkspacesConnectionStatusPaginator = client.get_paginator("describe_workspaces_connection_status")
list_available_management_cidr_ranges_paginator: ListAvailableManagementCidrRangesPaginator = client.get_paginator("list_available_management_cidr_ranges")
```

### Literals<a id="literals"></a>

`mypy_boto3_workspaces.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_workspaces.literals import (
    AccessPropertyValueType,
    ApplicationType,
    AssociationStatusType,
    ComputeType,
    ConnectionAliasStateType,
    ConnectionStateType,
    DedicatedTenancyModificationStateEnumType,
    DedicatedTenancySupportEnumType,
    DedicatedTenancySupportResultEnumType,
    DescribeAccountModificationsPaginatorName,
    DescribeIpGroupsPaginatorName,
    DescribeWorkspaceBundlesPaginatorName,
    DescribeWorkspaceDirectoriesPaginatorName,
    DescribeWorkspaceImagesPaginatorName,
    DescribeWorkspacesConnectionStatusPaginatorName,
    DescribeWorkspacesPaginatorName,
    ImageTypeType,
    ListAvailableManagementCidrRangesPaginatorName,
    ModificationResourceEnumType,
    ModificationStateEnumType,
    OperatingSystemTypeType,
    ReconnectEnumType,
    RunningModeType,
    TargetWorkspaceStateType,
    TenancyType,
    WorkspaceDirectoryStateType,
    WorkspaceDirectoryTypeType,
    WorkspaceImageIngestionProcessType,
    WorkspaceImageRequiredTenancyType,
    WorkspaceImageStateType,
    WorkspaceStateType,
)

def check_value(value: AccessPropertyValueType) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_workspaces.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_workspaces.type_defs import (
    AccountModificationTypeDef,
    AssociateConnectionAliasResultTypeDef,
    ClientPropertiesResultTypeDef,
    ClientPropertiesTypeDef,
    ComputeTypeTypeDef,
    ConnectionAliasAssociationTypeDef,
    ConnectionAliasPermissionTypeDef,
    ConnectionAliasTypeDef,
    CopyWorkspaceImageResultTypeDef,
    CreateConnectionAliasResultTypeDef,
    CreateIpGroupResultTypeDef,
    CreateWorkspaceBundleResultTypeDef,
    CreateWorkspacesResultTypeDef,
    DefaultWorkspaceCreationPropertiesTypeDef,
    DescribeAccountModificationsResultTypeDef,
    DescribeAccountResultTypeDef,
    DescribeClientPropertiesResultTypeDef,
    DescribeConnectionAliasPermissionsResultTypeDef,
    DescribeConnectionAliasesResultTypeDef,
    DescribeIpGroupsResultTypeDef,
    DescribeTagsResultTypeDef,
    DescribeWorkspaceBundlesResultTypeDef,
    DescribeWorkspaceDirectoriesResultTypeDef,
    DescribeWorkspaceImagePermissionsResultTypeDef,
    DescribeWorkspaceImagesResultTypeDef,
    DescribeWorkspaceSnapshotsResultTypeDef,
    DescribeWorkspacesConnectionStatusResultTypeDef,
    DescribeWorkspacesResultTypeDef,
    FailedCreateWorkspaceRequestTypeDef,
    FailedWorkspaceChangeRequestTypeDef,
    ImagePermissionTypeDef,
    ImportWorkspaceImageResultTypeDef,
    IpRuleItemTypeDef,
    ListAvailableManagementCidrRangesResultTypeDef,
    MigrateWorkspaceResultTypeDef,
    ModificationStateTypeDef,
    OperatingSystemTypeDef,
    PaginatorConfigTypeDef,
    RebootRequestTypeDef,
    RebootWorkspacesResultTypeDef,
    RebuildRequestTypeDef,
    RebuildWorkspacesResultTypeDef,
    RootStorageTypeDef,
    SelfservicePermissionsTypeDef,
    SnapshotTypeDef,
    StartRequestTypeDef,
    StartWorkspacesResultTypeDef,
    StopRequestTypeDef,
    StopWorkspacesResultTypeDef,
    TagTypeDef,
    TerminateRequestTypeDef,
    TerminateWorkspacesResultTypeDef,
    UserStorageTypeDef,
    WorkspaceAccessPropertiesTypeDef,
    WorkspaceBundleTypeDef,
    WorkspaceConnectionStatusTypeDef,
    WorkspaceCreationPropertiesTypeDef,
    WorkspaceDirectoryTypeDef,
    WorkspaceImageTypeDef,
    WorkspacePropertiesTypeDef,
    WorkspaceRequestTypeDef,
    WorkspaceTypeDef,
    WorkspacesIpGroupTypeDef,
)

def get_structure() -> AccountModificationTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-workspaces` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-workspaces docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workspaces/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
